@@ -13,13 +13,10 @@ sub run
 
     Gungho::Inline->run(
         {
-            user_agent => "Install Test For Gungho $Gungho::VERSION",
             engine => {
                 module => $engine,
             },
-            components => [
-                'BlockPrivateIP'
-            ]
+            block_private_ip_address => 1,
         },
         {
             provider => sub {
@@ -33,9 +30,9 @@ sub run
                     http://172.31.255.254
                     http://192.168.0.1
                     http://192.168.255.254
+                    http://localhost
                     http://224.0.0.1
                 )
-#                    http://localhost
             },
             handler => sub {
                 my ($p, $c, $req, $res) = @_;
